"use strict";
import { getApiRequestHeaders } from "./helpers/index.js";
function check(domain, userAgentIdentifier) {
  if (typeof domain === "string") {
    return checkAgainstAPI(domain, userAgentIdentifier);
  } else {
    return checkDomainsAgainstAPI(domain, userAgentIdentifier);
  }
}
async function checkAgainstAPI(domain, userAgentIdentifier) {
  const req = await fetch(`https://api.thegreenwebfoundation.org/greencheck/${domain}`, {
    headers: getApiRequestHeaders(userAgentIdentifier)
  });
  const res = await req.json();
  return res.green;
}
async function checkDomainsAgainstAPI(domains, userAgentIdentifier) {
  try {
    const apiPath = "https://api.thegreenwebfoundation.org/v2/greencheckmulti";
    const domainsString = JSON.stringify(domains);
    const req = await fetch(`${apiPath}/${domainsString}`, {
      headers: getApiRequestHeaders(userAgentIdentifier)
    });
    const allGreenCheckResults = await req.json();
    return greenDomainsFromResults(allGreenCheckResults);
  } catch (e) {
    return [];
  }
}
function greenDomainsFromResults(greenResults) {
  const entries = Object.entries(greenResults);
  const greenEntries = entries.filter(([key, val]) => val.green);
  return greenEntries.map(([key, val]) => val.url);
}
var hosting_api_default = {
  check
};
export {
  hosting_api_default as default
};
